@@ -3,7 +3,7 @@ from .random import RandomTool
 from .context import ContextTool
 from .constant import ConstantTool
 from .param import ParamTool
-from .string import JoinTool, SlugifyTool
+from .string import JoinTool, ReplaceTool, SlugifyTool
 
 tools = {
     'constant': ConstantTool(),
@@ -12,5 +12,6 @@ tools = {
     'faker': FakerTool(),
     'random': RandomTool(),
     'string.join': JoinTool(),
+    'string.replace': ReplaceTool(),
     'string.slugify': SlugifyTool(),
 }
