@@ -7,4 +7,4 @@ class JoinTool(ITool):
     def exec(self, ctx: ToolContext, args: Any = None) -> Any:
         assert ('sep' in args), "No separator specified for join function" + self.to_string(ctx)
         assert ('parts' in args), "No parts specified for join function" + self.to_string(ctx)
-        return args['sep'].join(args['parts'])
+        return str(args['sep']).join(args['parts'])
